@@ -1,13 +1,8 @@
-
 <style type="text/css">
-textarea#sql_code {
+textarea#sql_code, .codemirror {
 	width: 98%;
 	height: 200px;
 	margin: auto;
 	text-align: left;
 }
-
-form {
-	text-align: center;
-}
-</style>
\ No newline at end of file
+</style>
